@@ -260,8 +260,6 @@ Glib::ustring Field::sql(const Gnome::Gda::Value& value, const Glib::RefPtr<Gnom
     std::cerr << G_STRFUNC << ": The DataHandler was null." << std::endl;
     return Glib::ustring();
   }
-
-  return Glib::ustring();
 }
 
 #define GLOM_QUOTE_FOR_FILE_FORMAT "\""
@@ -326,8 +324,7 @@ Glib::ustring Field::to_file_format(const Gnome::Gda::Value& value, glom_field_t
     if(!str)
       return Glib::ustring();
 
-    Glib::ustring result = (str) ? 
-      Glib::ustring(Glib::ScopedPtr<char>(str).get()) : Glib::ustring();
+    Glib::ustring result = Glib::ustring(Glib::ScopedPtr<char>(str).get());
 
     //Correction for text representations of image (binary) data:
     //Avoid arbitrary newlines in this text.
@@ -469,6 +466,8 @@ Gnome::Gda::SqlOperatorType Field::sql_find_operator() const
       break;
     }
   }
+
+  return Gnome::Gda::SQL_OPERATOR_TYPE_EQ;
 }
 
 
