@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/data_structure/layout/layoutitem_portal.h>
@@ -79,16 +79,6 @@ LayoutItem_Portal& LayoutItem_Portal::operator=(const LayoutItem_Portal& src)
   return *this;
 }
 
-Glib::ustring LayoutItem_Portal::get_part_type_name() const
-{
-  //TODO: "Portal" probably shouldn't appear in the UI.
-  //We should use "Related Records instead.
-  //Translators: This is the name of a UI element (a layout part name).
-  //It means a list of related records.
-  return _("Portal");
-}
-
-
 void LayoutItem_Portal::change_related_field_item_name(const Glib::ustring& table_name, const Glib::ustring& field_name, const Glib::ustring& field_name_new)
 {
   LayoutGroup::change_related_field_item_name(table_name, field_name, field_name_new);
