@@ -113,10 +113,10 @@ void FlowTableWithFields::add_layout_item(const sharedptr<LayoutItem>& item)
   }
   else
   {
-    sharedptr<LayoutItem_Portal> portal = sharedptr<LayoutItem_Portal>::cast_dynamic(item);
-    if(portal)
+    sharedptr<LayoutGroup> group = sharedptr<LayoutGroup>::cast_dynamic(item);
+    if(group)
     {
-      add_layout_portal(portal);
+      add_layout_group_or_derived(group);
     }
     else
     {
@@ -153,6 +153,27 @@ void FlowTableWithFields::add_layout_item(const sharedptr<LayoutItem>& item)
   }
 }
 
+void FlowTableWithFields::add_layout_group_or_derived(const sharedptr<LayoutGroup>& group, bool with_indent)
+{
+  sharedptr<LayoutItem_Portal> portal = sharedptr<LayoutItem_Portal>::cast_dynamic(group);
+  if(portal)
+  {
+    add_layout_portal(portal);
+  }
+  else
+  {
+    sharedptr<LayoutItem_Notebook> notebook = sharedptr<LayoutItem_Notebook>::cast_dynamic(group);
+    if(notebook)
+    {
+      add_layout_notebook(notebook);
+    }
+    else
+    {
+      add_layout_group(group, with_indent);
+    }
+  }
+}
+          
 void FlowTableWithFields::add_layout_group(const sharedptr<LayoutGroup>& group, bool with_indent)
 {
   if(!group)
