@@ -45,7 +45,10 @@ Dialog_ChooseField::Dialog_ChooseField(BaseObjectType* cobject, const Glib::RefP
 
   builder->get_widget("button_select", m_button_select);
   builder->get_widget_derived("combobox_relationship", m_combo_relationship);
-  m_combo_relationship->signal_changed().connect(sigc::mem_fun(*this, &Dialog_ChooseField::on_combo_relationship_changed));
+  if(m_combo_relationship)
+  {
+    m_combo_relationship->signal_changed().connect(sigc::mem_fun(*this, &Dialog_ChooseField::on_combo_relationship_changed));
+  }
 
   builder->get_widget("treeview_fields", m_treeview);
 
@@ -273,7 +276,6 @@ Dialog_ChooseField::type_list_field_items Dialog_ChooseField::get_fields_chosen(
     field->set_related_relationship(related_relationship);
     field->set_full_field_details(field_details); //So is_same_field() can work.
 
-    field->set_full_field_details(field_details);
     field->set_name(row[m_ColumnsFields.m_col_name]);
     
     list_fields.push_back(field);
