@@ -14,14 +14,15 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_UTILITY_WIDGETS_ADDDEL_WITHBUTTONS_H
 #define GLOM_UTILITY_WIDGETS_ADDDEL_WITHBUTTONS_H
 
 #include "adddel.h"
+#include <gtkmm/buttonbox.h>
 
 namespace Glom
 {
@@ -37,6 +38,18 @@ public:
   virtual void set_allow_delete(bool val = true); //override
   virtual void set_allow_user_actions(bool bVal = true); //override
 
+  /**
+   * @param label The button label text, including the mnemonic underline.
+   */
+  void set_edit_button_label(const Glib::ustring& label);
+
+  /** Set the label of the extra button, if any.
+   * If there is no label text (the default) then the button will not be shown.
+   *
+   * @param label The button label text, including the mnemonic underline.
+   */
+  void set_extra_button_label(const Glib::ustring& label);
+
 private:
   void init();
   void setup_buttons();
@@ -44,12 +57,18 @@ private:
   void on_button_add();
   void on_button_del();
   void on_button_edit();
+  void on_button_extra();
+
+  virtual void show_all_vfunc();
 
   //member widgets:
   Gtk::ButtonBox m_ButtonBox;
   Gtk::Button m_Button_Add;
   Gtk::Button m_Button_Del;
   Gtk::Button m_Button_Edit;
+  Gtk::Button m_Button_Extra;
+
+  Glib::ustring m_label_extra;
 };
 
 } //namespace Glom
