@@ -59,6 +59,14 @@ static bool do_test(Glom::Document::HostingMode hosting_mode, const Glib::ustrin
     return false;
   }
 
+  const Glom::DbUtils::type_vec_strings table_names =
+    Glom::DbUtils::get_table_names_from_database();
+  if(std::find(table_names.begin(), table_names.end(), renamed_table_name)
+    != table_names.end()) {
+    std::cerr << G_STRFUNC << ": Failure: The dropped table seems to still exist." << std::endl;
+    return false;
+  }
+
   test_selfhosting_cleanup();
  
   return true; 
